;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "terraform-mode" "20251115.2210"
  "Major mode for terraform configuration file."
  '((emacs    "24.3")
    (hcl-mode "0.03")
    (dash     "2.17.0"))
  :url "https://github.com/syohex/emacs-terraform-mode"
  :commit "01635df3625c0cec2bb4613a6f920b8569d41009"
  :revdesc "01635df3625c"
  :authors '(("Syohei YOSHIDA" . "syohex@gmail.com"))
  :maintainers '(("Syohei YOSHIDA" . "syohex@gmail.com")))
